@@ -166,6 +166,10 @@ class ClientSession(urllib.request.BaseHandler):
         return hndlr.process_auth_request(request)
 
 
+    def https_request(self, request):
+        return self.http_request(request)
+
+
     def http_error_401(self, request, response, code, msg, hdrs):
         h = hdrs.get('WWW-Authenticate')
         if h == None:
@@ -217,3 +221,7 @@ class ClientSession(urllib.request.BaseHandler):
 
     def process_auth_request(self, request):
         return request
+
+
+    def __str__(self):
+        return 'usumbufu ' + str(self.__handlers[:len(self.__handlers)-1])
